diff src/status.h @ 10337:682201b69107

[gaim-migrate @ 11545] * Preliminary reading of status.xml using xmlnode.[h|c] * I made a few changes the blist.xml readering code that I think makes it cleaner * "gaim_statuses_find_saved" makes more sense to me than "gaim_statuses_find_stored" * struct GaimStatus isn't really supposed to be used for keeping the saved statuses, is it? I don't see how that would work. It seems to make more sense to have a separate data structure for it. Maybe I'm not seeing things clearly. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 09 Dec 2004 03:55:19 +0000
parents 393f85d9f8dd
children 84d73473c019
line wrap: on
line diff
--- a/src/status.h	Thu Dec 09 03:10:30 2004 +0000
+++ b/src/status.h	Thu Dec 09 03:55:19 2004 +0000
@@ -25,10 +25,12 @@
 #ifndef _GAIM_STATUS_H_
 #define _GAIM_STATUS_H_
 
-typedef struct _GaimStatusType   GaimStatusType;
-typedef struct _GaimStatusAttr   GaimStatusAttr;
-typedef struct _GaimPresence     GaimPresence;
-typedef struct _GaimStatus       GaimStatus;
+typedef struct _GaimStatusType      GaimStatusType;
+typedef struct _GaimStatusAttr      GaimStatusAttr;
+typedef struct _GaimPresence        GaimPresence;
+typedef struct _GaimStatus          GaimStatus;
+typedef struct _GaimStatusSavedSub  GaimStatusSavedSub;
+typedef struct _GaimStatusSaved     GaimStatusSaved;
 
 /**
  * A context for a presence.
@@ -879,29 +881,37 @@
 
 /*@}*/
 
-
 /**************************************************************************/
 /** @name Status subsystem                                                */
 /**************************************************************************/
 /*@{*/
 
 /**
  * Returns all stored statuses.
  *
  * @return A list of stored statuses.
  */
-const GList *gaim_statuses_get_stored(void);
+const GList *gaim_statuses_get_saved(void);
 
 /**
  * Finds a stored status with the specified status type and primary ID.
  *
  * @param status_type The status type of the status.
  * @param id          The primary attribute ID.
  *
  * @return The stored status if found, or NULL.
  */
-GaimStatus *gaim_statuses_find_stored(const GaimStatusType *status_type,
-									  const char *id);
+GaimStatusSaved *gaim_statuses_find_saved(const GaimStatusType *status_type,
+										  const char *id);
+
+/**
+ * Return the name of a given saved status.
+ *
+ * @param saved_status The saved status.
+ *
+ * @return The name.
+ */
+const char *gaim_statuses_saved_get_name(const GaimStatusSaved *saved_status);
 
 /**
  * Get the handle for the status subsystem.
@@ -879,29 +881,37 @@
 
 /**
- * Returns all stored statuses.
+ * Returns all saved statuses.
  *
@@ -879,29 +881,37 @@
  *
- * @return A list of stored statuses.
+ * @return A list of saved statuses.
  */
@@ -879,29 +881,37 @@
 
 /**
- * Finds a stored status with the specified status type and primary ID.
+ * Finds a saved status with the specified status type and primary ID.
  *
  * @param status_type The status type of the status.
@@ -879,29 +881,37 @@
  * @param id          The primary attribute ID.
  *
- * @return The stored status if found, or NULL.
+ * @return The saved status if found, or NULL.
  */